@@ -1,9 +1,10 @@
 import os
 
+
 DATABASES = {
     'default': {
         'ENGINE': 'django.db.backends.sqlite3',
-        'NAME': 'docs.db',
+        'NAME': os.path.join(os.path.dirname(__file__), 'docs.db'),
     }
 }
 
@@ -13,3 +14,11 @@ LOCAL_ROOT = os.path.abspath(os.path.join(os.path.dirname(__file__), 'data'))
 ADMINS = [
     ('Example Admin', 'admin@example.com'),
 ]
+
+# Set this in order to bypass code that auto-fills the database with
+# SCMTool data.
+RUNNING_TEST = True
+
+ENABLED_FEATURES = {
+    'diffviewer.dvcs': True,
+}
